@@ -381,7 +381,13 @@ class Transformer(BaseAgent):
         except Exception as ex:
             self.logger.error(ex)
             self.logger.error(traceback.format_exc())
-            transform_parameters = {'status': TransformStatus.Failed,
+            if transform['retries'] > 10:
+                tf_status = TransformStatus.Failed
+            else:
+                tf_status = TransformStatus.Transforming
+            transform_parameters = {'status': tf_status,
+                                    'next_poll_at': datetime.datetime.utcnow() + datetime.timedelta(seconds=self.poll_time_period * 4),
+                                    'retries': transform['retries'] + 1,
                                     'locking': TransformLocking.Idle}
             ret = {'transform': transform, 'transform_parameters': transform_parameters}
         return ret
@@ -692,11 +698,17 @@ class Transformer(BaseAgent):
                     break
 
             if not all_outputs_available:
-                for content in inputs + outputs + inputs_dependency:
+                for content in inputs + outputs:
                     update_content = {'content_id': content['content_id'],
                                       'status': ContentStatus.New,
                                       'substatus': ContentStatus.New}
                     updated_contents.append(update_content)
+                for content in inputs_dependency:
+                    if content['status'] not in [ContentStatus.Available]:
+                        update_content = {'content_id': content['content_id'],
+                                          'status': ContentStatus.New,
+                                          'substatus': ContentStatus.New}
+                        updated_contents.append(update_content)
         return updated_contents
 
     def process_running_transform_real(self, transform):
@@ -866,6 +878,7 @@ class Transformer(BaseAgent):
             work.tosuspend = True
         elif transform['status'] in [TransformStatus.ToResume]:
             transform['status'] = TransformStatus.Resuming
+            transform['retries'] = 0
             work.toresume = True
             to_resume_transform = True
             reactivated_contents = self.reactive_contents(registered_input_output_maps)
@@ -965,6 +978,7 @@ class Transformer(BaseAgent):
                                 'locking': TransformLocking.Idle,
                                 'workload_id': transform['workload_id'],
                                 'next_poll_at': next_poll_at,
+                                'retries': transform['retries'],
                                 'transform_metadata': transform['transform_metadata']}
         # if transform_substatus:
         #     transform_parameters['substatus'] = transform_substatus
@@ -1013,9 +1027,15 @@ class Transformer(BaseAgent):
         except Exception as ex:
             self.logger.error(ex)
             self.logger.error(traceback.format_exc())
+            if transform['retries'] > 10:
+                tf_status = TransformStatus.Failed
+            else:
+                tf_status = TransformStatus.Transforming
             ret = {'transform': transform,
-                   'transform_parameters': {'status': TransformStatus.Failed,
+                   'transform_parameters': {'status': tf_status,
+                                            'next_poll_at': datetime.datetime.utcnow() + datetime.timedelta(seconds=self.poll_time_period * 4),
                                             'locking': TransformLocking.Idle,
+                                            'retries': transform['retries'] + 1,
                                             'errors': {'msg': '%s: %s' % (ex, traceback.format_exc())}}}
         return ret
 
@@ -1034,7 +1054,13 @@ class Transformer(BaseAgent):
         except Exception as ex:
             self.logger.error(ex)
             self.logger.error(traceback.format_exc())
-            transform_parameters = {'status': TransformStatus.Failed,
+            if transform['retries'] > 10:
+                tf_status = TransformStatus.Failed
+            else:
+                tf_status = TransformStatus.Transforming
+            transform_parameters = {'status': tf_status,
+                                    'next_poll_at': datetime.datetime.utcnow() + datetime.timedelta(seconds=self.poll_time_period * 4),
+                                    'retries': transform['retries'] + 1,
                                     'locking': TransformLocking.Idle}
             ret = {'transform': transform, 'transform_parameters': transform_parameters}
         return ret
