@@ -6,7 +6,7 @@
 # http://www.apache.org/licenses/LICENSE-2.0OA
 #
 # Authors:
-# - Wen Guan, <wen.guan@cern.ch>, 2020
+# - Wen Guan, <wen.guan@cern.ch>, 2020 - 2021
 
 
 """
@@ -21,7 +21,7 @@ from idds.client.client import Client
 from idds.common.constants import RequestType, RequestStatus
 from idds.common.utils import get_rest_host
 
-from idds.workflow.work import Work, Parameter, WorkStatus
+from idds.workflow.work import Work   # Parameter, WorkStatus
 from idds.workflow.workflow import Condition, Workflow
 
 
@@ -36,30 +36,22 @@ class TestWorkflow(unittest.TestCase):
         work2 = Work(executable='echo',
                      arguments='--in=IN_DATASET --out=OUT_DATASET',
                      sandbox=None,
-                     parameters=Parameter({'IN_DATASET': 'data17:data17.test.raw.1',
-                                           'OUT_DATASET': 'data17:data17.test.work2'}),
                      work_id=2,
-                     input_collection_scope='data17',
-                     input_collection_name='data17.test.raw.1',
-                     output_collection_scope='data17',
-                     output_collection_name='data17.test.work2')
+                     primary_input_collection={'scope': 'data17', 'name': 'data17.test.raw.1'},
+                     output_collections=[{'scope': 'data17', 'name': 'data17.test.work2'}])
         work3 = Work(executable='echo',
                      arguments='--in=IN_DATASET --out=OUT_DATASET',
                      sandbox=None,
-                     parameters=Parameter({'IN_DATASET': 'data17:data17.test.work2',
-                                           'OUT_DATASET': 'data17:data17.test.work3'}),
                      work_id=3,
-                     input_collection_scope='data17',
-                     input_collection_name='data17.test.work2',
-                     output_collection_scope='data17',
-                     output_collection_name='data17.test.work3')
+                     primary_input_collection={'scope': 'data17', 'name': 'data17.test.work2'},
+                     output_collections=[{'scope': 'data17', 'name': 'data17.test.work3'}])
 
         workflow = Workflow()
         workflow.add_work(work1, initial=True)
         workflow.add_work(work2, initial=True)
         workflow.add_work(work3, initial=False)
 
-        cond = Condition(cond=work2.is_finished, prework=work2, true_work=work3)
+        cond = Condition(cond=work2.is_finished, true_work=work3)
         workflow.add_condition(cond)
 
         return workflow
@@ -71,52 +63,34 @@ class TestWorkflow(unittest.TestCase):
         work2 = Work(executable='echo',
                      arguments='--in=IN_DATASET --out=OUT_DATASET',
                      sandbox=None,
-                     parameters=Parameter({'IN_DATASET': 'data17:data17.test.raw.1',
-                                           'OUT_DATASET': 'data17:data17.test.work2'}),
                      work_id=2,
-                     input_collection_scope='data17',
-                     input_collection_name='data17.test.raw.1',
-                     output_collection_scope='data17',
-                     output_collection_name='data17.test.work2')
+                     primary_input_collection={'scope': 'data17', 'name': 'data17.test.raw.1'},
+                     output_collections=[{'scope': 'data17', 'name': 'data17.test.work2'}])
         work3 = Work(executable='echo',
                      arguments='--in=IN_DATASET --out=OUT_DATASET',
                      sandbox=None,
-                     parameters=Parameter({'IN_DATASET': 'data17:data17.test.work2',
-                                           'OUT_DATASET': 'data17:data17.test.work3'}),
                      work_id=3,
-                     input_collection_scope='data17',
-                     input_collection_name='data17.test.work2',
-                     output_collection_scope='data17',
-                     output_collection_name='data17.test.work3')
+                     primary_input_collection={'scope': 'data17', 'name': 'data17.test.work2'},
+                     output_collections=[{'scope': 'data17', 'name': 'data17.test.work3'}])
 
         workflow = Workflow()
         workflow.add_work(work1, initial=True)
         workflow.add_work(work2, initial=True)
         workflow.add_work(work3, initial=False)
 
-        cond = Condition(cond=work2.is_finished, prework=work2, true_work=work3)
+        cond = Condition(cond=work2.is_finished, true_work=work3)
+        # print(cond.all_works())
         workflow.add_condition(cond)
 
         # check
-        workflow_str = workflow.serialize()
-        workflow1 = Workflow.deserialize(workflow_str)
+        # workflow_str = workflow.serialize()
+        # workflow1 = Workflow.deserialize(workflow_str)
         # print(workflow_str)
         # print(workflow1)
-        works = workflow1.get_current_works()
+        works = workflow.get_current_works()
         # print([str(work) for work in works])
-        assert(works == [work1, work2])
-
-        works = workflow.get_current_works()
-        # print(works)
-        assert(works == [work1, work2])
-
-        workflow.update_work_status(work1, WorkStatus.Finished)
-        works = workflow.get_current_works()
-        assert(works == [work2])
-
-        workflow.update_work_status(work2, WorkStatus.Finished)
-        works = workflow.get_current_works()
-        assert(works == [work3])
+        # print([w.work_id for w in works])
+        assert(works == [])
 
     def test_workflow_request(self):
         workflow = self.init()
@@ -130,7 +104,7 @@ class TestWorkflow(unittest.TestCase):
             'status': RequestStatus.New,
             'priority': 0,
             'lifetime': 30,
-            'request_metadata': {'workload_id': '20776840', 'workflow': workflow.serialize()}
+            'request_metadata': {'workload_id': '20776840', 'workflow': workflow}
         }
 
         # print(props)
